{*******************************************************************************
* Unit      : TSLockPK Demostration program "LockPK"                           *
********************************************************************************
* Purpose   : Demonstration/Example program for the SLockPK component          *
*             This program is intended to provide SLockPK users with ideas     *
*             and examples how to use the SLockPK component to achieve         *
*             successful results. You are at liberty to use sections of this   *
*             example code in your applications when you have purchased a      *
*             license for SLockPK                                              *
********************************************************************************
* Copyright : This software  is copyright TSM Inc. 1998-1999                   *
*             This source code may not be distributed to third parties in      *
*             or in part without the written permission of TSM Inc.            *
*             All rights reserved. Liability limited to replacement of         *
*             this original source code in the case of loss or damage because  *
*             the use or misuse of this software.                              *
********************************************************************************
* Version   : 22.04.99  - 2.00  PK version "SLockPK"                           *
********************************************************************************
* Switches  : None                                                             *
*******************************************************************************}
unit RegFrm;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, ShellApi, Clipbrd;

type
  TfrmRegister = class(TForm)
    grpRegInfo: TGroupBox;
    pnlButtons: TPanel;
    btnDone: TButton;
    edtName: TEdit;
    lblName: TLabel;
    btnEncrypt: TButton;
    bvlStep1: TBevel;
    bvlStep2: TBevel;
    lblStep1: TLabel;
    lblSeeHelpFile: TLabel;
    btnTSMWeb: TButton;
    edtEmail: TEdit;
    lblEmail: TLabel;
    edtAddress1: TEdit;
    lblAddress1: TLabel;
    edtAddress2: TEdit;
    lblAddress2: TLabel;
    edtComment: TEdit;
    lblComment: TLabel;
    Label1: TLabel;
    mmoUserInfo: TMemo;
    btnPurchase: TButton;
    btnCopyToClip: TButton;
    procedure btnDoneClick(Sender: TObject);
    procedure btnEncryptClick(Sender: TObject);
    procedure edtNameChange(Sender: TObject);
    procedure btnPurchaseClick(Sender: TObject);
    procedure btnTSMWebClick(Sender: TObject);
    procedure btnCopyToClipClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
  end;

var
  frmRegister: TfrmRegister;

implementation

uses
     SlockFrm, Slock;

{$R *.DFM}

{*******************************************************************************
* Procedure : TfrmRegister.btnCloseClick                                       *
********************************************************************************
* Purpose   : This closes the window                                           *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRegister.btnDoneClick(Sender: TObject);
begin
     Close;
end; {TfrmRegister.btnDoneClick}

{*******************************************************************************
* Procedure : TfrmRegister.btnEncryptClick                                     *
********************************************************************************
* Purpose   : This gathers the information from the user information fields    *
*             and packs it into the user information record.                   *
*                                                                              *
*             The user information record is then encrypted using the          *
*             GetUserInfoString function which encrypts the information and    *
*             packages it ready for transmission over the net.                 *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRegister.btnEncryptClick(Sender: TObject);
var
     UserInfo: TUserInfo;
     TempString: string;
begin
     // clear the old memo text
     mmoUserInfo.Lines.Clear;

     // create the user information record
     UserInfo.UserName := edtName.Text;
     UserInfo.UserEmail := edtEmail.Text;
     UserInfo.UserAddress := edtAddress1.Text + ', ' + edtAddress2.Text;
     UserInfo.UserCreditCard := '';
     UserInfo.UserCCExpiry := '';
     UserInfo.UserComment := edtComment.Text;

     // create the certificate
     TempString := frmMain.Slock1.GetUserInfoString(UserInfo);

     // display the User Info record in the memo field
     mmoUserInfo.Lines.Add(TempString);
end; {TfrmRegister.btnEncryptClick}

{*******************************************************************************
* Procedure : TfrmRegister.edtNameChange                                       *
********************************************************************************
* Purpose   : Enables the "Encrypt" button when the minimum amount of info     *
*             has been entered by the user. In this case we require a name and *
*             the email addresss. You may decide that other fields are "must"  *
*             fields for your application                                      *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRegister.edtNameChange(Sender: TObject);
begin
     btnEncrypt.Enabled :=  ((Length(edtName.Text) > 0) and
                            (Length(edtEmail.Text) > 0));
end; {TfrmRegister.edtNameChange}

{*******************************************************************************
* Procedure : TfrmRegister.btnPurchaseClick                                    *
********************************************************************************
* Purpose   : Opens a browser window to the KAGI order site                    *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRegister.btnPurchaseClick(Sender: TObject);
begin
     ShellExecute(GetDesktopWindow(), nil, PChar('http://order.kagi.com/?GDS'), nil, nil, SW_SHOWNORMAL);
end; {TfrmRegister.btnPurchaseClick}

{*******************************************************************************
* Procedure : TfrmRegister.btnTSMWebClick                                      *
********************************************************************************
* Purpose   : Opens a browser window to the TSM main window                    *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRegister.btnTSMWebClick(Sender: TObject);
begin
     ShellExecute(GetDesktopWindow(), nil,
                  PChar('http://www.crypto-central.com/index.html'),
                  nil, nil, SW_SHOWNORMAL);
end; {TfrmRegister.btnTSMWebClick}

{*******************************************************************************
* Procedure : TfrmRegister.btnCopyToClipClick                                  *
********************************************************************************
* Purpose   : Copy the contents of the memo field to the clipboard             *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRegister.btnCopyToClipClick(Sender: TObject);
begin
     mmoUserInfo.SelectAll;
     mmoUserInfo.CopyToClipboard;
end; {TfrmRegister.btnCopyToClipClick}

procedure TfrmRegister.FormCreate(Sender: TObject);
begin
     // fill in the user name if we know it
     edtName.Text := frmMain.Slock1.RegName;
end;

end.
